cfr_part returns a data_frame year, title, volume, chapters, parts, and file path for each xml file
cfr_part(file_path, verbose = FALSE)file path coming from the bulk download
logical. Will return "helpful" messages regarding the status of the file path.
Numeric (year, title, volume, and chapters) and characters (parts and file path).
cfr_part
Since we're after more refined data than a single volume, we need to figure out what chapters and parts are associated with each volume. This function parses the xml and scrapes the Table of Contents for the information held in each volume.